@@ -8,4 +8,4 @@
 NULL
 
 # suppress R CMD CHECK notes on variables that are internal to this package.
-globalVariables(c("..density..","level","varname","verticalPosition","dom"))
\ No newline at end of file
+globalVariables(c("..density..","level","varname","verticalPosition","dom","yr","mn"))
\ No newline at end of file
