@@ -14,7 +14,6 @@
 #' @export
 #' @examples 
 #' terrestrial_core_sites()
-#'
 terrestrial_core_sites <- function() {
 
   # core sites as of 190523.
@@ -56,7 +55,7 @@ terrestrial_relocatable_sites <- function() {
 #' @return A vector listing NEON sites measuring water vapor isotope ratios.
 #'
 #' @author Rich Fiorella \email{rich.fiorella@@utah.edu}
-#' @keywords internal
+#' 
 
 water_isotope_sites <- function() {
 
@@ -171,11 +170,12 @@ manage_local_EC_archive <- function(file_dir,
           dl_urls  <- furls[fnames_basic]
           
           for (k in 1:length(dl_names)) {
-            print(dl_names[k])
             if (!length(dl_names[k])==0) {
               if (!is.na(dl_names[k])) {
                 # check to see if file exists in folder
-                if (file.exists(paste0(file_dir, site_name, "/", dl_names[k]))) {
+                if (file.exists(paste0(file_dir, site_name, "/", dl_names[k])) |
+                    file.exists(paste0(file_dir, site_name, "/", 
+                                       substr(dl_names[k],1,nchar(dl_names[k])-3)))) {
                   print(paste(dl_names[k], "exists...skipping..."))
                   next      
                 } else { #doesn't exist, so download it.
